{% extends "wooey/modals/base_modal.html" %}
{% load i18n %}
{% block modal_id %}modal-permalink{% endblock %}
{% block modal_title %}{% trans "Permanant link to these results" %}{% endblock modal_title %}
{% block modal_body %}
<p>{% trans "You can share the following link to give open access to your results:" %}</p>
<p><a href="{{ permalink }}">{{ permalink }}</a></p>
<p>Anyone with this link will be able to view your data — only share with people you trust! <!-- If you
want to give more restricted access, use user-by-user sharing.--></p>
{% endblock modal_body %}
