{% load i18n %}
{% load wooey_tags %}
<form class="navbar-form" method="post" action="{% url 'wooey:wooey_login' %}">
    {% csrf_token %}
  <div class="form-group form-group-sm">
    <input name="username" type="username" class="form-control" id="username" placeholder="{% trans "Username" %}">
  </div>
  <div class="form-group form-group-sm">
    <input name="password" type="password" class="form-control" id="password" placeholder="Password">
  </div>
    <input type="hidden" name="next" value="{{ request.path }}" />
  <button type="submit" class="btn btn-default btn-sm" id="wooey-login">{% trans "Login" %}</button>
{% get_wooey_setting "WOOEY_REGISTER_URL" as registration_url %}
{% if registration_url %}
{#    This is a hack but it gets register aligned properly without any work#}
    <div class="form-group"><li>&nbsp;&nbsp;<a href="{% url "wooey:wooey_register" %}">{% trans "Register" %}</a></li></div>
{% endif %}
</form>
